@@ -18,9 +18,11 @@ DL_FUNC R_ExternalPtrAddrFn(SEXP s) {
 #endif
 
 SEXP rlang_namespace(const char* ns) {
-  SEXP call = PROTECT(Rf_lang2(Rf_install("getNamespace"), Rf_mkString(ns)));
+  SEXP ns_string = PROTECT(Rf_mkString(ns));
+  SEXP call = PROTECT(Rf_install("getNamespace"));
+  call = PROTECT(Rf_lang2(call, ns_string));
   SEXP ns_env = Rf_eval(call, R_BaseEnv);
-  UNPROTECT(1);
+  UNPROTECT(3);
   return ns_env;
 }
 
@@ -30,8 +32,10 @@ void rlang_register_pointer(const char* ns, const char* ptr_name, DL_FUNC fn) {
   SEXP ptr_obj = PROTECT(Rf_allocVector(VECSXP, 1));
   SET_VECTOR_ELT(ptr_obj, 0, ptr);
 
-  Rf_setAttrib(ptr_obj, R_ClassSymbol, Rf_mkString("fn_pointer"));
+  SEXP ptr_class = PROTECT(Rf_mkString("fn_pointer"));
+  Rf_setAttrib(ptr_obj, R_ClassSymbol, ptr_class);
 
-  Rf_defineVar(Rf_install(ptr_name), ptr_obj, rlang_namespace(ns));
-  UNPROTECT(2);
+  SEXP ns_env = PROTECT(rlang_namespace(ns));
+  Rf_defineVar(Rf_install(ptr_name), ptr_obj, ns_env);
+  UNPROTECT(4);
 }
